@@ -1,18 +1,22 @@
 import logging
-import pathlib
 from typing import Any, Dict, List, Optional
 
 import objc
 from Foundation import NSArray, NSUUID, NSBundle
 from CoreBluetooth import CBPeripheral
+from typing_extensions import Literal
 
 from bleak.backends.corebluetooth.CentralManagerDelegate import CentralManagerDelegate
 from bleak.backends.corebluetooth.utils import cb_uuid_to_str
 from bleak.backends.device import BLEDevice
-from bleak.backends.scanner import BaseBleakScanner, AdvertisementData
+from bleak.backends.scanner import (
+    AdvertisementDataCallback,
+    BaseBleakScanner,
+    AdvertisementData,
+)
+from bleak.exc import BleakError
 
 logger = logging.getLogger(__name__)
-_here = pathlib.Path(__file__).parent
 
 
 class BleakScannerCoreBluetooth(BaseBleakScanner):
@@ -27,19 +31,36 @@ class BleakScannerCoreBluetooth(BaseBleakScanner):
     this for the BLEDevice address on macOS.
 
     Args:
-        **timeout (double): The scanning timeout to be used, in case of missing
-          ``stopScan_`` method.
-        **detection_callback (callable or coroutine):
+        detection_callback:
             Optional function that will be called each time a device is
             discovered or advertising data has changed.
-        **service_uuids (List[str]):
+        service_uuids:
             Optional list of service UUIDs to filter on. Only advertisements
             containing this advertising data will be received. Required on
-            macOS 12 and later (unless you create an app with ``py2app``).
+            macOS >= 12.0, < 12.3 (unless you create an app with ``py2app``).
+        scanning_mode:
+            Set to ``"passive"`` to avoid the ``"active"`` scanning mode. Not
+            supported on macOS! Will raise :class:`BleakError` if set to
+            ``"passive"``
+        **timeout (float):
+             The scanning timeout to be used, in case of missing
+            ``stopScan_`` method.
     """
 
-    def __init__(self, **kwargs):
-        super(BleakScannerCoreBluetooth, self).__init__(**kwargs)
+    def __init__(
+        self,
+        detection_callback: Optional[AdvertisementDataCallback] = None,
+        service_uuids: Optional[List[str]] = None,
+        scanning_mode: Literal["active", "passive"] = "active",
+        **kwargs
+    ):
+        super(BleakScannerCoreBluetooth, self).__init__(
+            detection_callback, service_uuids
+        )
+
+        if scanning_mode == "passive":
+            raise BleakError("macOS does not support passive scanning")
+
         self._identifiers: Optional[Dict[NSUUID, Dict[str, Any]]] = None
         self._manager = CentralManagerDelegate.alloc().init()
         self._timeout: float = kwargs.get("timeout", 5.0)
